[> Documentation-Index](index.md) [> Implementation Guide](implementation-overview.md)

# HbbTV Sample App
<sub>Implementation Guideline</sub>

## 3. Safeguarding the Video Player: The Player Facade
The Player Facade translates calls from the <span style="color:#E4002B">smartclient**core**</span> to methods of the Player API.
The **facade for the sample app** can be found in `js/ceHtmlFacade.js`. 

It must be included next to the player API source file. 

```diff
--- index.html
+++ index.html

 	<script type="text/javascript" crossorigin="anonymous" src="vendor_modules/smartclip/smartclientcore.min.js"></script>
+	<script type="text/javascript" crossorigin="anonymous" src="js/ceHtmlFacade.js"></script>
 	<script type="text/javascript" crossorigin="anonymous" src="js/main.js"></script>
```
<sub>Extract from the _index.html_ :: Adding the **player facade**</sub>

### Background
In order to avoid unexpected calls to the player API, it is **mandatory to safeguard the player API 
with a player-specific facade**. 

Using the facade has two main reasons:
- Provide a generic player interface the <span style="color:#E4002B">smartclient**core**</span> can safely talk to
- Capture and validate requests made by the <span style="color:#E4002B">smartclient**core**</span> towards the player API

To get you started, please have a look at the [Facade and Video Player Interface](../vendor_modules/smartclip/docs/FacadeBase.md)
specification and get familiar with the common facade class that can be found in `vendor_modules/smartclip/FacadeBase.js`.

<span class="box box--buttercup">Regardless of whether the facade could solve other tasks, 
like loading a new source requested by a playlist controller, the facade should be reserved to 
handle requests from the smartclient**core** only. 
It makes debugging much easier, if the facade is used from only one direction.</span>


Next: [Creating an Ad Controller](implementation-ad-controller.md)  
Prev: [Installing the smartclient**core**](implementation-installing.md)    
Top: [Implementation Guide Overview](implementation-overview.md)
