window.onload = function() {

	// The CE-HTML VideoObject interface covers methods and properties to load, play and monitor a video.
	// Therewith we have it already, that is the most simple Player API.
	window.playerAPI = document.getElementById('myvid');
	
	// Detects whether we run in a HbbTV channel and registers our sample app.
	initHBBTV = function () {
		
		// The oipfApplicationManager enables the HbbTV browser of the SmartTV to display the HbbTV content.
		var app = document.getElementById('oipfAppMan');
		if (app && app.getOwnerApplication) app = app.getOwnerApplication(document);
		if (app && app.show) app.show(); // needed to show the HbbTV app on screen
		if (app && app.activate) app.activate();
		if (app && app.privateData) app.privateData.keyset.setValue(0x33F); // color + nav + vcr + numeric + alpha
	};
	
	// Register the sample app with the HbbTV browser.
	initHBBTV();
	
	/**
	 * Creates a log entry and appends it to the Event Log layer.
	 * @param {AdEvent} event
	 */
	writeLog = function(event) {
		var logDate = new Date(event.timestamp);
		var hours = (logDate.getHours() < 10 ? '0' : '') + logDate.getHours();
		var mins = (logDate.getMinutes() < 10 ? '0' : '') + logDate.getMinutes();
		var secs = (logDate.getSeconds() < 10 ? '0' : '') + logDate.getSeconds();
		
		var lineType = '';
		var errorMessage = null;
		var issuer = adController.publisherAPI && adController.publisherAPI.ad && adController.publisherAPI.ad.info && adController.publisherAPI.ad.info.variant ? adController.publisherAPI.ad.info.variant : '';
		
		if (event.type.indexOf('Info') > -1) {
			lineType = 'logview__line--info';
			errorMessage = event.text;
		}
		
		if (event.type.indexOf('Error') > -1) {
			lineType = 'logview__line--error';
			errorMessage = adController.publisherAPI.ad && adController.publisherAPI.ad.error && adController.publisherAPI.ad.error.code ? adController.publisherAPI.ad.error.code + '<br>' + adController.publisherAPI.ad.error.description : '';
		}
		
		if (event.type.indexOf('Warning') > -1) {
			lineType = 'logview__line--warn';
			errorMessage = adController.publisherAPI.ad && adController.publisherAPI.ad.error && adController.publisherAPI.ad.error.code ? adController.publisherAPI.ad.error.code : '';
		}
		
		if (event.type.indexOf('AdSlot') === 0) {
			lineType = 'logview__line--adslot';
		}
		
		if (event.type.indexOf('Detected') > -1 || event.type.indexOf('SkippableState') > -1) {
			lineType = 'logview__line--info';
		}
		
		// output to the Debugger UI or console
		var log = '<tr class="logview__line ' + lineType + '">';
		log += '<td class="logview__line__timestamp">' + hours + ':' + mins + ':' + secs + '</td>';
		log += '<td class="logview__line__prefix">' + issuer + '</td>';
		log += '<td class="logview__line__content">' + event.type + ' ' + (errorMessage ? errorMessage : '') + '</td>';
		log += '</tr>';
		
		if (event.type === 'AdStopped' || event.type === 'AdSkipped') {
			// add a line to visually separate ads from one another
			log = '<tr class="logview__line"><td class="logview__line" colspan="3"><hr class="logview__separator"></td></tr>' + log;
		}
		if (event.type === 'AdSlotComplete') {
			// add a line to visually separate slots from one another
			log = '<tr class="logview__line"><td class="logview__line" colspan="3"><hr class="logview__separator logview__separator--adslot"></td></tr>' + log;
			
			// slot over, do the same as a click on stopAdSlot would do
			//_onStop();
		}
		
		var logger = document.getElementById('event-list');
		logger.insertAdjacentHTML('afterbegin', log);
	};
	
	// --- START AdController Implementation ---
	
	/**
	 * Initialize the AdController and prepare the smartclientcore
	 * - Initialize your player facade
	 * - Connect it with the smartclientcore
	 * - Setup global advertising parameters
	 * - Get the publisher API
	 */
	adController = new AdController();
	adController.createPlayerFacade(window.playerAPI);
	adController.initSmartClientCore();
	
	applyAdScheduleAndStartPlayback = function(schedule) {
		
		adController.applyAdSchedule(schedule);
		
		// For testing purpose we quickly jump to a playback position that is
		//  5 seconds ahead of the execution time of the first scheduled ad break
		var firstAdBreak = adController.testAdBreak[schedule[0]];
		var playbackOffset = Math.max((firstAdBreak.actualOffset - 5000), 0);
		
		if (window.playerAPI && window.playerAPI.play) {
			
			// Avoid jumping to negative offsets
			if (window.playerAPI.seek && playbackOffset > 0) {
				window.playerAPI.seek(playbackOffset);
			}
			
			// Start content playback
			window.playerAPI.play(1);
		}	// else? Hope the TV starts playback automatically
	};
	
	/**
	 * Subscribes to remote input events and calls the `handleRemoteInput` callback below.
	 * @returns {void}
	 */
	initRemoteInputListener = function() {
		document.addEventListener('keydown', function(e) {
			if (handleRemoteInput(e.keyCode)) {
				e.preventDefault();
			}
		}, false);
	};
	
	/**
	 * Capture input from the TV's remote control
	 * @param {number} keyCode for the pressed remote button
	 * @returns {boolean} Whether we handle the input or not
	 */
	handleRemoteInput = function (keyCode) {
		switch (keyCode) {
			case 403:	// button--red
				applyAdScheduleAndStartPlayback(['preroll', 'midroll', 'postroll']);
				return true;
				break;
			case 404:	// button--green
				applyAdScheduleAndStartPlayback(['preroll']);
				return true;
				break;
			case 405:	// button--yellow
				applyAdScheduleAndStartPlayback(['midroll']);
				return true;
				break;
			case 406:	// button--blue
				applyAdScheduleAndStartPlayback(['postroll']);
				return true;
				break;
		}
		
		return false;
	};
	
	// The colored buttons on the remote control are used to start the test cases.
	initRemoteInputListener();
	
// --- END AdController Implementation ---
};
